@@ -1,15 +1,15 @@
-use 5.14.0;
+use 5.12.0;
 use warnings;
-use Dist::Iller::Standard;
 
-# PODNAME: Dist::Iller::Config::Author::CSSON
-# ABSTRACT: Dist::Iller config
+package Dist::Iller::Config::Author::CSSON {
 
-class Dist::Iller::Config::Author::CSSON using Moose with Dist::Iller::Role::Config {
-
-    our $VERSION = '0.0105'; # VERSION
+    our $VERSION = '0.0106'; # VERSION
+    # ABSTRACT: Dist::Iller config
 
+    use Moose;
     use Path::Tiny;
+    use Types::Path::Tiny qw/Path/;
+    use Types::Standard qw/Bool Str Int/;
     use MooseX::AttributeDocumented;
 
     has filepath => (
@@ -68,18 +68,23 @@ class Dist::Iller::Config::Author::CSSON using Moose with Dist::Iller::Role::Con
             1 => q{Include [TravisYML]. By default it tests 5.14+},
         },
     );
+    with 'Dist::Iller::Role::Config';
 
-    method build_file {
+    sub build_file {
+        my $self = shift;
         return $self->installer =~ m/MakeMaker/ ? 'Makefile.PL' : 'Build.PL';
     }
 
-    method is_private_release {
+    sub is_private_release {
+        my $self = shift;
         return !$ENV{'FAKE_RELEASE'} && $self->is_private ? 1 : 0;
     }
-    method is_cpan_release {
+    sub is_cpan_release {
+        my $self = shift;
         return $ENV{'FAKE_RELEASE'} || $self->is_private ? 0 : 1;
     }
-    method add_default_github {
+    sub add_default_github {
+        my $self = shift;
         # check git config
         my $add_default_github = 0;
         my $git_config = path('.git/config');
@@ -108,9 +113,24 @@ __END__
 
 Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.12+-brightgreen.svg" alt="Requires Perl 5.12+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-40.9%-red.svg" alt="coverage 40.9%" /></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.12+](https://img.shields.io/badge/perl-5.12+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON) ![coverage 40.9%](https://img.shields.io/badge/coverage-40.9%-red.svg)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.0105, released 2016-01-22.
+Version 0.0106, released 2016-01-23.
 
 
 
@@ -442,7 +462,7 @@ L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>
 
 =head1 HOMEPAGE
 
-L<http://metacpan.org/release/Dist-Iller-Config-Author-CSSON>
+L<https://metacpan.org/release/Dist-Iller-Config-Author-CSSON>
 
 =head1 AUTHOR
 
